#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://loemu.pegueroles.com/body.html

# Package name
NAME="loemu"
# Package version
VERSION="0.3.1"
# Source code URL
SOURCE="http://loemu.pegueroles.com/dists/loemu-$VERSION.tar.gz"
# Files that should be placed in /usr/doc/package-version/
DOCS="README ADDING CHANGES PKG-INFO"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="60.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: loemu is a PyGTK frontend for game emulators
$NAME:
$NAME: loemu supports game emulation with xmame, sdlmame and snes9x.You
$NAME: can Browse games using dynamic list. This allows to browse in a
$NAME: list generated with some categories (and it has other advantages).
$NAME: You can finds games quickly, using a specific dialog that looks for
$NAME: a game in all the gamelist. The generation of subsets of the
$NAME: gamelist is very fast.
$NAME:
$NAME:
$NAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Check to see if icons are present. If it's not, download it
if [ -f icons.tar.gz ]; then
	echo "Icon file already here, no need to download";
else
 	echo "Downloading icon file"
	wget -c http://users.zenwalk.org/user-accounts/gapan/$NAME/icons.tar.gz
fi

# Unpack source
tar xvzf $NAME-$VERSION.tar.gz
tar xvf icons.tar.gz

# Create the desktop entry
mkdir -p $PKG/usr/share/applications
cat > $PKG/usr/share/applications/$NAME.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Loemu
Exec=loemu
Terminal=false
Type=Application
Categories=Game;Emulator;
Icon=loemu
EOF

# Configure and make
cd $NAME-$VERSION
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
python setup.py build

# Install on temporary directory
python setup.py install --root=$PKG

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION

# Compress the man page(s)
find $PKG/usr/man -type f -exec gzip -9 {} \;

# Copy icons to the right place
ICONSIZES="48 32 24 22 16"
for i in $ICONSIZES; do
	mkdir -p $PKG/usr/share/icons/hicolor/$i\x$i/apps;
	mv $CWD/$NAME-$i.png $PKG/usr/share/icons/hicolor/$i\x$i/apps/$NAME.png;
done;

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
/sbin/makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG
